@@ -4,36 +4,23 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-02-21'; # DATE
+our $DATE = '2024-04-12'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20240221.0'; # VERSION
+our $VERSION = '20240412.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
-    'KIMOTO' => '',
-    'PMQS' => '',
-    'JV' => '',
-    'LITCHIE' => '',
     'PERLANCAR' => '',
+    'SIDNEY' => '',
+    'BRIANDFOY' => '',
+    'MATHIAS' => '',
+    'PEVANS' => '',
+    'CORION' => '',
+    'INGY' => '',
+    'LEONT' => '',
     'NHORNE' => '',
-    'OETIKER' => '',
+    'PAYJP' => '',
+    'SKIM' => '',
     'TYRRMINAL' => '',
-    'ABALAMA' => '',
-    'FASTLY' => '',
-    'JIMAVERA' => '',
-    'KJETILK' => '',
-    'OALDERS' => '',
-    'OODLER' => '',
-    'RAWLEYFOW' => '',
-    'SANKO' => '',
-    'VOLKENING' => '',
-    'CRORAA' => '',
-    'DWHEELER' => '',
-    'ETJ' => '',
-    'GBROWN' => '',
-    'JDDPAUSE' => '',
-    'KRYDE' => '',
-    'MLEHMANN' => '',
-    'VVELOX' => '',
 );
 
 
@@ -52,42 +39,29 @@ Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current - Authors with ongoing
 
 =head1 VERSION
 
-This document describes version 20240221.0 of Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-02-21.
+This document describes version 20240412.0 of Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-04-12.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2024-02-21, produced by L<cpan-streaks>):
+Current standings (as of 2024-04-12, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | KIMOTO    |   3 | 2024-02-18 | ongoing     |
-  | PMQS      |   3 | 2024-02-18 | ongoing     |
-  | JV        |   2 | 2024-02-18 | might-break |
-  | LITCHIE   |   2 | 2024-02-18 | might-break |
-  | PERLANCAR |   2 | 2024-02-18 | might-break |
-  | NHORNE    |   2 | 2024-02-19 | ongoing     |
-  | OETIKER   |   2 | 2024-02-19 | ongoing     |
-  | TYRRMINAL |   2 | 2024-02-19 | ongoing     |
-  | ABALAMA   |   1 | 2024-02-19 | might-break |
-  | FASTLY    |   1 | 2024-02-19 | might-break |
-  | JIMAVERA  |   1 | 2024-02-19 | might-break |
-  | KJETILK   |   1 | 2024-02-19 | might-break |
-  | OALDERS   |   1 | 2024-02-19 | might-break |
-  | OODLER    |   1 | 2024-02-19 | might-break |
-  | RAWLEYFOW |   1 | 2024-02-19 | might-break |
-  | SANKO     |   1 | 2024-02-19 | might-break |
-  | VOLKENING |   1 | 2024-02-19 | might-break |
-  | CRORAA    |   1 | 2024-02-20 | ongoing     |
-  | DWHEELER  |   1 | 2024-02-20 | ongoing     |
-  | ETJ       |   1 | 2024-02-20 | ongoing     |
-  | GBROWN    |   1 | 2024-02-20 | ongoing     |
-  | JDDPAUSE  |   1 | 2024-02-20 | ongoing     |
-  | KRYDE     |   1 | 2024-02-20 | ongoing     |
-  | MLEHMANN  |   1 | 2024-02-20 | ongoing     |
-  | VVELOX    |   1 | 2024-02-20 | ongoing     |
+  | PERLANCAR |  50 | 2024-02-23 | ongoing     |
+  | SIDNEY    |  12 | 2024-03-31 | might-break |
+  | BRIANDFOY |   2 | 2024-04-10 | might-break |
+  | MATHIAS   |   2 | 2024-04-10 | might-break |
+  | PEVANS    |   2 | 2024-04-10 | might-break |
+  | CORION    |   1 | 2024-04-11 | might-break |
+  | INGY      |   1 | 2024-04-11 | might-break |
+  | LEONT     |   1 | 2024-04-11 | might-break |
+  | NHORNE    |   1 | 2024-04-11 | might-break |
+  | PAYJP     |   1 | 2024-04-11 | might-break |
+  | SKIM      |   1 | 2024-04-11 | might-break |
+  | TYRRMINAL |   1 | 2024-04-11 | might-break |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
